@@ -1,6 +1,6 @@
 from sdccli.cli.formatter.text_formatter import alert, dashboard, panel
 from sdccli.cli.formatter.text_formatter.scanning import alert as scanning_alert
-from sdccli.cli.formatter.text_formatter.scanning import image
+from sdccli.cli.formatter.text_formatter.scanning import image, vulnerability
 
 
 class NormalFormatter:
@@ -11,6 +11,7 @@ class NormalFormatter:
         self.formats.update(scanning_alert.formats())
         self.formats.update(image.formats())
         self.formats.update(panel.formats())
+        self.formats.update(vulnerability.formats())
 
     def format(self, response, format_type):
         if format_type in self.formats:
